@@ -269,7 +269,7 @@ Hello_App::new_app_cb()
 gint
 Hello_App::about_close_cb()
 {
-  printf("debug\n");
+  delete about_; //Destroys and closes it.
   about_ = 0;
 
   return TRUE;
