@@ -477,14 +477,25 @@ struct UIArrayHolder
 }
 
 
-void fill (Gtk::MenuShell& menu_shell,
-           const UI::Array<Info>& info,
-           Gtk::AccelGroup& accel_group,
-           gboolean         uline_accels,
-           gint             pos)
+void fill (Gtk::MenuShell&        menu_shell,
+	   const UI::Array<Info>& info,
+	   Gtk::AccelGroup&       accel_group,
+	   gboolean               uline_accels,
+	   gint                   pos)
 {
   menu_shell.set_data_full("gnomemm-uihold",new UIArrayHolder(info),UIArrayHolder::destroy);
-  gnome_app_fill_menu(menu_shell.gtkobj(), info.gtkobj(), accel_group.gtkobj(), uline_accels, pos);                  
+  gnome_app_fill_menu(menu_shell.gtkobj(), info.gtkobj(), accel_group.gtkobj(), uline_accels, pos);
+}
+
+UI::Array<Info> fill_and_return (Gtk::MenuShell&        menu_shell,
+				   const UI::Array<Info>& info,
+				   Gtk::AccelGroup&       accel_group,
+				   gboolean               uline_accels,
+				   gint                   pos)
+{
+  menu_shell.set_data_full("gnomemm-uihold",new UIArrayHolder(info),UIArrayHolder::destroy);
+  gnome_app_fill_menu(menu_shell.gtkobj(), info.gtkobj(), accel_group.gtkobj(), uline_accels, pos);
+  return info;
 }
 
 void fill (Gtk::Toolbar& toolbar, 
@@ -495,6 +506,15 @@ void fill (Gtk::Toolbar& toolbar,
   gnome_app_fill_toolbar(toolbar.gtkobj(), info.gtkobj(), accel_group.gtkobj());
 }
 
+UI::Array<Info> fill_and_return (Gtk::Toolbar& toolbar, 
+				 const UI::Array<Info> &info,
+				 Gtk::AccelGroup& accel_group)
+{
+  toolbar.set_data_full("gnomemm-uihold",new UIArrayHolder(info),UIArrayHolder::destroy);
+  gnome_app_fill_toolbar(toolbar.gtkobj(), info.gtkobj(), accel_group.gtkobj());
+  return info;
+}
+
 } /*namespace UI */
 
 } /* namespace Gnome */
